@@ -30,12 +30,15 @@ from ansible.playbook.taggable import Taggable
 
 class Block(Base, Become, Conditional, Taggable):
 
-    _block  = FieldAttribute(isa='list', default=[], inherit=False)
-    _rescue = FieldAttribute(isa='list', default=[], inherit=False)
-    _always = FieldAttribute(isa='list', default=[], inherit=False)
-    _delegate_to = FieldAttribute(isa='list')
-    _delegate_facts = FieldAttribute(isa='bool', default=False)
-    _any_errors_fatal = FieldAttribute(isa='bool')
+    # main block fields containing the task lists
+    _block            = FieldAttribute(isa='list', default=[], inherit=False)
+    _rescue           = FieldAttribute(isa='list', default=[], inherit=False)
+    _always           = FieldAttribute(isa='list', default=[], inherit=False)
+
+    # other fields
+    _delegate_to      = FieldAttribute(isa='string')
+    _delegate_facts   = FieldAttribute(isa='bool', default=False)
+    _name             = FieldAttribute(isa='string', default='')
 
     # for future consideration? this would be functionally
     # similar to the 'else' clause for exceptions
@@ -138,13 +141,13 @@ class Block(Base, Become, Conditional, Taggable):
     def _load_always(self, attr, ds):
         try:
             return load_list_of_tasks(
-                ds, 
+                ds,
                 play=self._play,
-                block=self, 
-                role=self._role, 
+                block=self,
+                role=self._role,
                 task_include=None,
-                variable_manager=self._variable_manager, 
-                loader=self._loader, 
+                variable_manager=self._variable_manager,
+                loader=self._loader,
                 use_handlers=self._use_handlers,
             )
         except AssertionError:
@@ -260,7 +263,7 @@ class Block(Base, Become, Conditional, Taggable):
                 p = TaskInclude()
             elif parent_type == 'HandlerTaskInclude':
                 p = HandlerTaskInclude()
-            p.deserialize(pb_data)
+            p.deserialize(parent_data)
             self._parent = p
             self._dep_chain = self._parent.get_dep_chain()
 
@@ -345,8 +348,8 @@ class Block(Base, Become, Conditional, Taggable):
                 if isinstance(task, Block):
                     tmp_list.append(evaluate_block(task))
                 elif task.action == 'meta' \
-                or (task.action == 'include' and task.evaluate_tags([], play_context.skip_tags, all_vars=all_vars)) \
-                or task.evaluate_tags(play_context.only_tags, play_context.skip_tags, all_vars=all_vars):
+                    or (task.action == 'include' and task.evaluate_tags([], play_context.skip_tags, all_vars=all_vars)) \
+                    or task.evaluate_tags(play_context.only_tags, play_context.skip_tags, all_vars=all_vars):
                     tmp_list.append(task)
             return tmp_list
 
